@@ -9,32 +9,7 @@
 #include <QDesktopServices>
 //#include <QtXml>
 //#include <QXmlSimpleReader>
-/*
-QWidget *ImageDelegate::createEditor(QWidget *parent,
-                                      const QStyleOptionViewItem &,
-                                      const QModelIndex &index) const
- {
-     QComboBox *comboBox = new QComboBox(parent);
-     if (index.column() == 1) {
-         comboBox->addItem(tr("Normal"));
-         comboBox->addItem(tr("Active"));
-         comboBox->addItem(tr("Disabled"));
-         comboBox->addItem(tr("Selected"));
-     } else if (index.column() == 2) {
-         comboBox->addItem(tr("Off"));
-         comboBox->addItem(tr("On"));
-     }
 
-     connect(comboBox, SIGNAL(activated(int)), this, SLOT(emitCommitData()));
-
-     return comboBox;
-
-     int pos = comboBox->findText(index.model()->data(index).toString(),
-                                  Qt::MatchExactly);
-
- }
-
-*/
 
 DetailWindow::DetailWindow(Target * target, bool edit, eWallet *paTarget, QWidget *parent) :
 		QMainWindow(parent)
@@ -51,6 +26,8 @@ DetailWindow::DetailWindow(Target * target, bool edit, eWallet *paTarget, QWidge
 		changeFields (0);
 	}
 
+	orgType = this->target->type;
+
 	deleteFace = false;
 	deleteBack = false;
 
@@ -144,13 +121,18 @@ DetailWindow::DetailWindow(Target * target, bool edit, eWallet *paTarget, QWidge
 
 		typeLineEdit = new QComboBox(this);
 
+		bool selected = false;
 		for(int i = 0; i < this->parent->types.size(); i++) {
 			typeLineEdit->addItem (this->parent->types[i], this->parent->types[i]);
 			if (target)
 				if (target->type == this->parent->types[i]) {
 					typeLineEdit->setCurrentIndex(i);
+					selected = true;
 				}
 		}
+		if (!selected) {
+			typeLineEdit->setCurrentIndex(this->parent->types.size() - 1);
+		}
 
 	    connect(typeLineEdit, SIGNAL(activated(int)), this, SLOT(emitCommitData(int)));
 
@@ -333,8 +315,8 @@ void DetailWindow::changeFields (int a) {
 		}
 	}
 
-	for (int i = 0; i < parent->fieldsByType [a].size(); i++) {
-		TargetField tmp = parent->fieldsByType [a][i];
+	for (int i = 0; i < parent->fieldsByType [a]->size(); i++) {
+		TargetField tmp = parent->fieldsByType [a]->at(i);
 
 		if (!target->existField (tmp.name)) {
 			TargetField * f;
@@ -452,6 +434,11 @@ void DetailWindow::saveTarget () {
 		currentImageN = NULL;
 		parent->_updateTargetPicture(target);
 	}
+	else {
+		if (orgType != target->type && target->getPicture() == NULL) {
+			parent->_updateTargetPicture(target);
+		}
+	}
 
 
 	if (deleteBack) {
@@ -517,7 +504,7 @@ void DetailWindow::cardMenu(const QPoint & _p) {
 
 	entryScrollArea->ensureVisible(p.x(), p.y());
 
-	if (this->imageLabel->geometry().contains(p)) {
+	if (this->imageLabel != NULL && this->imageLabel->geometry().contains(p)) {
 		QMenu menu(this);
 		if (edit) {
 			menu.addAction("Edit", this, SLOT(cardFace()));
@@ -529,7 +516,7 @@ void DetailWindow::cardMenu(const QPoint & _p) {
 		menu.exec(_p);
 	}
 	else
-	if (this->imageBackLabel->geometry().contains(p)) {
+	if (this->imageBackLabel != NULL && this->imageBackLabel->geometry().contains(p)) {
 		QMenu menu(this);
 		if (edit) {
 			menu.addAction("Edit", this, SLOT(cardBack()));
@@ -550,6 +537,18 @@ void DetailWindow::deleteCardFace()
 }
 void DetailWindow::exportCardFace()
 {
+	if (target->picture != NULL) {
+		QString path(QDesktopServices::storageLocation(QDesktopServices::PicturesLocation));
+		QString s = QFileDialog::getSaveFileName(
+	                this,
+	                "Choose card face image file",
+	                path,
+	                "Images (*.png)");
+		if (!s.isNull () && !s.isEmpty ()) {
+			s.append(".png");
+			target->picture->save(s, "PNG"); // writes image into ba in PNG format
+		}
+	}
 }
 void DetailWindow::cardFace()
 {
@@ -615,6 +614,18 @@ void DetailWindow::deleteCardBack()
 }
 void DetailWindow::exportCardBack()
 {
+	if (target->pictureBack != NULL) {
+		QString path(QDesktopServices::storageLocation(QDesktopServices::PicturesLocation));
+		QString s = QFileDialog::getSaveFileName(
+	                this,
+	                "Choose card back image file",
+	                path,
+	                "Images (*.png)");
+		if (!s.isNull () && !s.isEmpty ()) {
+			s.append(".png");
+			target->pictureBack->save(s, "PNG"); // writes image into ba in PNG format
+		}
+	}
 }
 void DetailWindow::cardBack()
 {
