@@ -169,3 +169,9 @@ void LoginDialog::keyPressEvent(QKeyEvent* event) {
 		}
 	}
 }
+/*
+void LoginDialog::focusOutEvent ( QFocusEvent * event ) {
+	
+	qDebug () << "LOST FOCUS";
+}
+*/
\ No newline at end of file
